# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-06 08:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sources', '0014_auto_20170206_0722'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sanescanner',
            name='source',
            field=models.CharField(blank=True, choices=[('flatbed', 'Flatbed'), ('Automatic Document Feeder', 'Document feeder')], default='flatbed', help_text='Selects the scan source (such as a document-feeder). If this option is not supported by your scanner, leave it blank.', max_length=32, verbose_name='Paper source'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-05 07:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sources', '0011_sanescanner'),
    ]

    operations = [
        migrations.AddField(
            model_name='sanescanner',
            name='mode',
            field=models.CharField(choices=[('lineart', 'Lineart'), ('monochrome', 'Monochrome'), ('color', 'Color')], default='color', max_length=16, verbose_name='Mode'),
        ),
        migrations.AddField(
            model_name='sanescanner',
            name='resolution',
            field=models.PositiveIntegerField(default=300, help_text='Sets the resolution of the scanned image in DPI (dots per inch).', verbose_name='Resolution'),
        ),
    ]



from __future__ import unicode_literals


class LockingBackend(object):
    """
    Base class for the lock backends. Defines the base methods that each
    subclass must define.
    """
    @classmethod
    def acquire_lock(cls, name, timeout=None):
        raise NotImplementedError

    @classmethod
    def purge_locks(cls):
        raise NotImplementedError



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-05 04:19
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sources', '0010_auto_20151001_0055'),
    ]

    operations = [
        migrations.CreateModel(
            name='SaneScanner',
            fields=[
                ('interactivesource_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='sources.InteractiveSource')),
                ('device_name', models.CharField(help_text='Device name as returned by the SANE backend.', max_length=255, verbose_name='Device name')),
            ],
            options={
                'verbose_name': 'SANE Scanner',
                'verbose_name_plural': 'SANE Scanners',
            },
            bases=('sources.interactivesource',),
        ),
    ]



from __future__ import unicode_literals

from django.apps import apps

from .base import LockingBackend


class ModelLock(LockingBackend):
    @classmethod
    def acquire_lock(cls, name, timeout=None):
        Lock = apps.get_model(app_label='lock_manager', model_name='Lock')
        return Lock.objects.acquire_lock(name=name, timeout=timeout)

    @classmethod
    def purge_locks(cls):
        Lock = apps.get_model(app_label='lock_manager', model_name='Lock')
        Lock.objects.select_for_update().delete()
